@@ -1,9 +1,10 @@
 import logging
 from datetime import datetime, timedelta
-from typing import Any
+from typing import Any, Iterable
 
 from redis import Redis
 from redis.exceptions import ConnectionError
+
 from request_time_tracker.notifiers.base import BaseNotifier
 from request_time_tracker.trackers.cache.base import BaseCacheQueueTimeTracker
 
@@ -21,6 +22,7 @@ class RedisCacheQueueTimeTracker(BaseCacheQueueTimeTracker):
         send_stats_every_seconds: int = 10,
         queue_time_header_name: str = None,
         notifier: BaseNotifier = None,
+        notifiers: Iterable[BaseNotifier] = None,
         redis_url: str = 'redis://localhost:6379/0',
         cache_key_prefix: str = 'queue-time',
     ):
@@ -29,6 +31,7 @@ class RedisCacheQueueTimeTracker(BaseCacheQueueTimeTracker):
             send_stats_every_seconds=send_stats_every_seconds,
             queue_time_header_name=queue_time_header_name,
             notifier=notifier,
+            notifiers=notifiers,
             cache_key_prefix=cache_key_prefix,
         )
         self.redis_url = redis_url
