@@ -1,4 +1,4 @@
-from request_time_tracker.django_wsgi import LegacyQueueTimeTracker as QueueTimeTracker  # noqa
+from request_time_tracker.django_wsgi import LegacyQueueTimeTracker as QueueTimeTracker  # noqa: legacy
 
 """
 Example:
