@@ -30,6 +30,6 @@ def noop():
     pass
 
 
-def get_time_in_millis():
-    start_time = datetime.now()
+def get_time_in_millis(start_time=None):
+    start_time = start_time or datetime.now()
     return '{0}.{1}'.format(int(start_time.timestamp()), int(start_time.microsecond / 1000))
